@@ -11,14 +11,18 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-#
-# =============================================================================
+
 import dwave.system.flux_bias_offsets
 
 from dwave.system.samplers import *
 import dwave.system.samplers
 
+from dwave.system.temperatures import *
+import dwave.system.temperatures
+
 from dwave.system.composites import *
 import dwave.system.composites
 
 from dwave.system.utilities import *
+
+from dwave.system.package_info import __version__
