@@ -11,9 +11,19 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-#
-# ================================================================================================
 
 
 class MissingFluxBias(Exception):
     """"""
+
+
+class FailoverCondition(Exception):
+    """QPU or Solver API call failed with an error that might be mitigated by
+    retrying on a different solver.
+    """
+
+
+class RetryCondition(FailoverCondition):
+    """QPU or Solver API call failed with an error that might be mitigated by
+    retrying on the same solver.
+    """
