@@ -19,7 +19,10 @@ See :std:doc:`Ocean Glossary <oceandocs:glossary>`
 for explanations of technical terms in descriptions of Ocean tools.
 """
 
+import copy
 import collections.abc as abc
+from collections import defaultdict
+from typing import Optional, Dict
 
 import dimod
 
@@ -28,13 +31,13 @@ from dwave.cloud.client import Client
 from dwave.cloud.exceptions import (
     SolverError, SolverAuthenticationError, InvalidAPIResponseError,
     RequestTimeout, PollingTimeout, ProblemUploadError, ProblemStructureError,
+    SolverNotFoundError,
 )
 
 from dwave.system.exceptions import FailoverCondition, RetryCondition
 from dwave.system.warnings import WarningHandler, WarningAction
 
 import dwave_networkx as dnx
-import networkx as nx
 
 __all__ = ['DWaveSampler', 'qpu_graph']
 
@@ -173,11 +176,35 @@ class DWaveSampler(dimod.Sampler, dimod.Structured):
             raise TypeError("mapping expected for 'defaults'")
         defaults.update(solver=dict(order_by='-num_active_qubits'))
 
-        self.client = Client.from_config(**config)
-        self.solver = self.client.get_solver()
-
         self.failover = failover
         self.retry_interval = retry_interval
+        self._solver_penalty = defaultdict(int)
+
+        self.client = Client.from_config(**config)
+        self.solver = self._get_solver(penalty=self._solver_penalty)
+
+    def _get_solver(self, *, refresh: bool = False, penalty: Optional[Dict[str, int]] = None):
+        """Get the least penalized solver from the list of solvers filtered and
+        ordered according to user config.
+
+        Note: we need to partially replicate :class:`dwave.cloud.Client.get_solver` logic.
+        """
+        if penalty is None:
+            penalty = {}
+
+        # the only solver filters used by `DWaveSampler` are those
+        # propagated to `Client.from_config` on construction
+        filters = copy.deepcopy(self.client.default_solver)
+        order_by = filters.pop('order_by', 'avg_load')
+        solvers = self.client.get_solvers(refresh=refresh, order_by=order_by, **filters)
+
+        # we now just need to de-prioritize penalized solvers
+        solvers.sort(key=lambda solver: penalty.get(solver.id, 0))
+
+        try:
+            return solvers[0]
+        except IndexError:
+            raise SolverNotFoundError("Solver with the requested features not available")
 
     warnings_default = WarningAction.IGNORE
     """Defines the default behavior for :meth:`.sample_ising`'s  and
@@ -255,12 +282,12 @@ class DWaveSampler(dimod.Sampler, dimod.Structured):
         """list: List of active couplers for the D-Wave solver.
 
         Examples:
-            Coupler list for one D-Wave 2000Q system (output snipped for brevity).
+            First 5 entries of the coupler list for one Advantage system.
 
             >>> from dwave.system import DWaveSampler
             >>> sampler = DWaveSampler()
-            >>> sampler.edgelist
-            [(0, 4), (0, 5), (0, 6), (0, 7), ...
+            >>> sampler.edgelist[:5]    # doctest: +SKIP
+            [(30, 31), (30, 45), (30, 2940), (30, 2955), (30, 2970)]
 
         See `Ocean Glossary <https://docs.ocean.dwavesys.com/en/stable/concepts/index.html>`_
         for explanations of technical terms in descriptions of Ocean tools.
@@ -279,12 +306,12 @@ class DWaveSampler(dimod.Sampler, dimod.Structured):
         """list: List of active qubits for the D-Wave solver.
 
         Examples:
-            Node list for one D-Wave 2000Q system (output snipped for brevity).
+            First 5 entries of the node list for one Advantage system.
 
             >>> from dwave.system import DWaveSampler
             >>> sampler = DWaveSampler()
-            >>> sampler.nodelist
-            [0, 1, 2, ...
+            >>> sampler.nodelist[:5]    # doctest: +SKIP
+            [30, 31, 32, 33, 34]
 
         See `Ocean Glossary <https://docs.ocean.dwavesys.com/en/stable/concepts/index.html>`_
         for explanations of technical terms in descriptions of Ocean tools.
@@ -300,9 +327,12 @@ class DWaveSampler(dimod.Sampler, dimod.Structured):
     def trigger_failover(self):
         """Trigger a failover and connect to a new solver."""
 
-        # the requested features are saved on the client object, so
-        # we just need to request a new solver
-        self.solver = self.client.get_solver(refresh=True)
+        # penalize the solver that just failed
+        self._solver_penalty[self.solver.id] += 1
+
+        # select the next solver in user-defined preference order, but try to
+        # avoid the penalized (failed) ones
+        self.solver = self._get_solver(refresh=True, penalty=self._solver_penalty)
 
         # delete the lazily-constructed attributes
         try:
@@ -555,13 +585,13 @@ class DWaveSampler(dimod.Sampler, dimod.Structured):
 
         Examples:
             This example converts a selected D-Wave system solver to a graph
-            and verifies it has over 2000 nodes.
+            and verifies it has over 5000 nodes.
 
             >>> from dwave.system import DWaveSampler
             ...
             >>> sampler = DWaveSampler()
             >>> g = sampler.to_networkx_graph()      # doctest: +SKIP
-            >>> len(g.nodes) > 2000                  # doctest: +SKIP
+            >>> len(g.nodes) > 5000                  # doctest: +SKIP
             True
         """
         return qpu_graph(self.properties['topology']['type'],
