@@ -25,18 +25,6 @@ from collections import abc
 
 import dimod
 
-try:
-    # dimod 0.10.x
-    from dimod.binary.binary_quadratic_model import BQM
-
-    bqm_to_file = BQM.to_file
-except ImportError:
-    # dimod 0.9.x
-    from dimod import AdjVectorBQM as BQM
-    from dimod.serialization.fileview import FileView
-
-    bqm_to_file = FileView
-
 from dwave.cloud import Client
 from dwave.system.utilities import classproperty, FeatureFlags
 
@@ -221,8 +209,8 @@ class LeapHybridSampler(dimod.Sampler):
             >>> sampleset = sampler.sample(bqm)           # doctest: +SKIP
 
         """
-        if not isinstance(bqm, BQM):
-            bqm = BQM(bqm)
+        if not isinstance(bqm, dimod.BQM):
+            bqm = dimod.BQM(bqm)
 
         num_vars = bqm.num_variables
 
@@ -246,7 +234,7 @@ class LeapHybridSampler(dimod.Sampler):
 
     def _sample(self, bqm, **kwargs):
         """Sample from the given BQM."""
-        with bqm_to_file(bqm, version=2) as fv:
+        with bqm.to_file(version=2) as fv:
             sapi_problem_id = self.solver.upload_bqm(fv).result()
 
         return self.solver.sample_bqm(sapi_problem_id, **kwargs).sampleset
@@ -255,7 +243,7 @@ class LeapHybridSampler(dimod.Sampler):
         """Sample from the unlabelled version of the BQM, then apply the
         labels to the returned sampleset.
         """
-        with bqm_to_file(bqm, version=2, ignore_labels=True) as fv:
+        with bqm.to_file(version=2, ignore_labels=True) as fv:
             sapi_problem_id = self.solver.upload_bqm(fv).result()
 
         sampleset = self.solver.sample_bqm(sapi_problem_id, **kwargs).sampleset
@@ -493,12 +481,11 @@ class LeapHybridDQMSampler:
                 )
             compress = compressed or compress
 
-        try:
-            f = dqm.to_file(compress=compress, ignore_labels=True)._file
-        except NotImplementedError:
-            f = dimod.DQM.to_file(dqm, compress=compress, ignore_labels=True)._file
+        with dqm.to_file(compress=compress, ignore_labels=True) as f:
+            sapi_problem_id = self.solver.upload_problem(f).result()
+
+        future = self.solver.sample_dqm(sapi_problem_id, time_limit=time_limit, **kwargs)
 
-        future = self.solver.sample_dqm(f, time_limit=time_limit, **kwargs)
         yield future
 
         sampleset = future.sampleset.relabel_variables(dict(enumerate(dqm.variables)))
@@ -707,53 +694,76 @@ class LeapHybridCQMSampler:
             raise TypeError("first argument 'cqm' must be a ConstrainedQuadraticModel, "
                             f"recieved {type(cqm).__name__}")
 
-        if time_limit is None:
-            time_limit = self.min_time_limit(cqm)
-        elif time_limit < self.min_time_limit(cqm):
-            raise ValueError("the minimum time limit for this problem is "
-                             f"{self.min_time_limit(cqm)} seconds "
-                             f"({time_limit}s provided), "
-                             "see .min_time_limit method")
+        # developer note: this is a temporary fix until
+        # https://github.com/dwavesystems/dimod/issues/1303 is fixed
+        # and should be reverted afterwards
+        with cqm.to_file() as fcqm:
+            data = dimod.serialization.fileview.read_header(
+                fcqm,
+                dimod.constrained.CQM_MAGIC_PREFIX,
+                ).data
 
-        contact_sales_str = "Contact D-Wave at sales@dwavesys.com if your " + \
-                            "application requires scale or performance that " + \
-                            "exceeds the currently advertised capabilities of " + \
-                            "this hybrid solver."
+            class _cqm:
+                # a fake CQM that has the same properties as the real thing,
+                # except it reports the num_biases of the serialized model.
+                # To remove once https://github.com/dwavesystems/dimod/issues/1303
+                # is fixed.
+                variables = cqm.variables
+                constraints = cqm.constraints
 
-        if len(cqm.constraints) > self.properties['maximum_number_of_constraints']:
-            raise ValueError(
-                "constrained quadratic model must have "
-                f"{self.properties['maximum_number_of_constraints']} or fewer "
-                f"constraints; given model has {len(cqm.constraints)}. "
-                f"{contact_sales_str}")
+                @staticmethod
+                def num_biases():
+                    return data['num_biases']
 
-        if len(cqm.variables) > self.properties['maximum_number_of_variables']:
-            raise ValueError(
-                "constrained quadratic model must have "
-                f"{self.properties['maximum_number_of_variables']} or fewer "
-                f"variables; given model has {len(cqm.variables)}. "
-                f"{contact_sales_str}")
+            if time_limit is None:
+                time_limit = self.min_time_limit(_cqm)
+            elif time_limit < self.min_time_limit(_cqm):
+                raise ValueError("the minimum time limit for this problem is "
+                                 f"{self.min_time_limit(_cqm)} seconds "
+                                 f"({time_limit}s provided), "
+                                 "see .min_time_limit method")
 
-        if cqm.num_biases() > self.properties['maximum_number_of_biases']:
-            raise ValueError(
-                "constrained quadratic model must have "
-                f"{self.properties['maximum_number_of_biases']} or fewer "
-                f"biases; given model has {cqm.num_biases()}. "
-                f"{contact_sales_str}")
+            contact_sales_str = "Contact D-Wave at sales@dwavesys.com if your " + \
+                                "application requires scale or performance that " + \
+                                "exceeds the currently advertised capabilities of " + \
+                                "this hybrid solver."
 
-        if cqm.num_quadratic_variables() > self.properties['maximum_number_of_quadratic_variables']:
-            raise ValueError(
-                "constrained quadratic model must have "
-                f"{self.properties['maximum_number_of_quadratic_variables']} "
-                "or fewer variables with at least one quadratic bias across "
-                "all constraints; given model has "
-                f"{cqm.num_quadratic_variables()}. "
-                f"{contact_sales_str}")
+            if len(cqm.constraints) > self.properties['maximum_number_of_constraints']:
+                raise ValueError(
+                    "constrained quadratic model must have "
+                    f"{self.properties['maximum_number_of_constraints']} or fewer "
+                    f"constraints; given model has {len(cqm.constraints)}. "
+                    f"{contact_sales_str}")
 
-        return self.solver.sample_cqm(cqm, time_limit=time_limit, **kwargs).sampleset
+            if len(cqm.variables) > self.properties['maximum_number_of_variables']:
+                raise ValueError(
+                    "constrained quadratic model must have "
+                    f"{self.properties['maximum_number_of_variables']} or fewer "
+                    f"variables; given model has {len(cqm.variables)}. "
+                    f"{contact_sales_str}")
+
+            if _cqm.num_biases() > self.properties['maximum_number_of_biases']:
+                raise ValueError(
+                    "constrained quadratic model must have "
+                    f"{self.properties['maximum_number_of_biases']} or fewer "
+                    f"biases; given model has {cqm.num_biases()}. "
+                    f"{contact_sales_str}")
+
+            if cqm.num_quadratic_variables(include_objective=False) > self.properties['maximum_number_of_quadratic_variables']:
+                raise ValueError(
+                    "constrained quadratic model must have "
+                    f"{self.properties['maximum_number_of_quadratic_variables']} "
+                    "or fewer variables with at least one quadratic bias across "
+                    "all constraints; given model has "
+                    f"{cqm.num_quadratic_variables()}. "
+                    f"{contact_sales_str}")
+
+            sapi_problem_id = self.solver.upload_problem(fcqm).result()
+
+        return self.solver.sample_cqm(sapi_problem_id, time_limit=time_limit, **kwargs).sampleset
 
     def min_time_limit(self, cqm: dimod.ConstrainedQuadraticModel) -> float:
-        """Return the minimum `time_limit` accepted for the given problem."""
+        """Return the minimum `time_limit`, in seconds, accepted for the given problem."""
 
         # todo: remove the hard-coded defaults
         num_variables_multiplier = self.properties.get('num_variables_multiplier', 1.57e-04)
